#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-unlifted
version:              2.2.0.0
visibility:           public
id:                   primitive-unlifted-2.2.0.0-BjXmK3op6amGQuLJMAbKuj
key:                  primitive-unlifted-2.2.0.0-BjXmK3op6amGQuLJMAbKuj
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           andrew.thaddeus@gmail.com
author:               Andrew Martin
homepage:             https://github.com/haskell-primitive/primitive-unlifted
synopsis:             Primitive GHC types with unlifted types inside
description:
    Primitive GHC types with unlifted types inside. There used
    to be a module named `Data.Primitive.UnliftedArray` in the
    `primitive` library. However, it turns out that it is impossible
    to write such an API safely in versions of GHC before 8.10.1, thanks
    to some nasty interactions between unsafe coercions and the foreign
    function interface. This package also uses a somewhat different,
    and more flexible, approach than that module did.

category:             Data
abi:                  0a071a808949a48b11ea60ec97c1d4a4
exposed:              True
exposed-modules:
    Data.Primitive.TArray.Classic Data.Primitive.Unlifted.Array
    Data.Primitive.Unlifted.Array.Primops
    Data.Primitive.Unlifted.Array.ST Data.Primitive.Unlifted.Box
    Data.Primitive.Unlifted.Class Data.Primitive.Unlifted.MVar
    Data.Primitive.Unlifted.MVar.Primops
    Data.Primitive.Unlifted.MVar.ST Data.Primitive.Unlifted.MutVar
    Data.Primitive.Unlifted.MutVar.Primops
    Data.Primitive.Unlifted.MutVar.ST
    Data.Primitive.Unlifted.SmallArray
    Data.Primitive.Unlifted.SmallArray.Primops
    Data.Primitive.Unlifted.SmallArray.ST Data.Primitive.Unlifted.Type
    Data.Primitive.Unlifted.Weak Data.Primitive.Unlifted.Weak.IO
    Data.Primitive.Unlifted.Weak.Primops

import-dirs:          /usr/lib/ghc-9.6.6/site-local/primitive-unlifted-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/primitive-unlifted-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/primitive-unlifted-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-unlifted
hs-libraries:         HSprimitive-unlifted-2.2.0.0-BjXmK3op6amGQuLJMAbKuj
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3
    primitive-0.9.1.0-BFOZgwmJzy9HvkVKyhwLqr
    text-short-0.1.6.1-oo923UdzYsCTZa3wWoX5D

haddock-interfaces:
    /usr/share/doc/haskell-primitive-unlifted/html/primitive-unlifted.haddock

haddock-html:         /usr/share/doc/haskell-primitive-unlifted/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

